@@ -1,20 +1,20 @@
 /*
-  Copyright (C) 2003-2010 FreeIPMI Core Team
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2, or (at your option)
-  any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA
-*/
+ * Copyright (C) 2003-2010 FreeIPMI Core Team
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
 
 #if HAVE_CONFIG_H
 #include "config.h"
@@ -670,7 +670,7 @@ display_system_info_common (bmc_info_state_data_t *state_data,
   if (func_cmd_first_set (state_data->ipmi_ctx,
                           IPMI_GET_SYSTEM_INFO_PARAMETER,
                           set_selector,
-                          IPMI_SYSTEM_INFO_NO_BLOCK_SELECTOR,
+                          IPMI_SYSTEM_INFO_PARAMETERS_NO_BLOCK_SELECTOR,
                           obj_cmd_first_set_rs) < 0)
     {
       if (!state_data->prog_data->args->get_system_info
@@ -751,7 +751,7 @@ display_system_info_common (bmc_info_state_data_t *state_data,
       if (func_cmd (state_data->ipmi_ctx,
                     IPMI_GET_SYSTEM_INFO_PARAMETER,
                     set_selector,
-                    IPMI_SYSTEM_INFO_NO_BLOCK_SELECTOR,
+                    IPMI_SYSTEM_INFO_PARAMETERS_NO_BLOCK_SELECTOR,
                     obj_cmd_rs) < 0)
         {
           if (!state_data->prog_data->args->get_system_info
