@@ -1,20 +1,20 @@
 /*
-  Copyright (C) 2003-2010 FreeIPMI Core Team
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2, or (at your option)
-  any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA
-*/
+ * Copyright (C) 2003-2010 FreeIPMI Core Team
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
 
 #ifndef _TOOL_SENSOR_COMMON_H
 #define _TOOL_SENSOR_COMMON_H
@@ -79,8 +79,6 @@ struct sensor_entity_id_counts
 const char * get_sensor_type_output_string (unsigned int sensor_type);
 const char * get_oem_sensor_type_output_string (uint8_t sensor_type, uint8_t event_reading_code, uint32_t manufacturer_id, uint16_t product_id);
 
-void get_sensor_type_cmdline_string (char *sensor_type);
-
 int get_entity_sensor_name_string (pstdout_state_t pstate,
                                    ipmi_sdr_parse_ctx_t sdr_parse_ctx,
                                    const void *sdr_record,
@@ -90,24 +88,13 @@ int get_entity_sensor_name_string (pstdout_state_t pstate,
                                    char *sensor_name_buf,
                                    unsigned int sensor_name_buf_len);
 
-int get_entity_sensor_name_string_by_record_id (pstdout_state_t pstate,
-                                                ipmi_sdr_parse_ctx_t sdr_parse_ctx,
-                                                ipmi_sdr_cache_ctx_t sdr_cache_ctx,
-                                                uint16_t record_id,
-                                                struct sensor_entity_id_counts *entity_id_counts,
-                                                uint8_t *sensor_number,
-                                                char *sensor_name_buf,
-                                                unsigned int sensor_name_buf_len);
+int list_sensor_types (pstdout_state_t pstate);
 
-int display_sensor_type_cmdline (pstdout_state_t pstate, 
-                                 unsigned int sensor_type);
-
-int display_string_cmdline (pstdout_state_t pstate, 
-                            const char *str);
-
-int sensor_type_strcmp (pstdout_state_t pstate,
-                        const char *sensor_type_str_input,
-                        unsigned int sensor_type);
+/* 1 if all valid, 0 if not, -1 on error */
+int valid_sensor_types (pstdout_state_t pstate,
+                        char sensor_types[][MAX_SENSOR_TYPES_STRING_LENGTH+1],
+                        unsigned int sensor_types_length,
+                        unsigned int allow_oem_reserved);
 
 int get_sensor_units_output_string (pstdout_state_t pstate,
                                     ipmi_sdr_parse_ctx_t sdr_parse_ctx,
@@ -117,12 +104,17 @@ int get_sensor_units_output_string (pstdout_state_t pstate,
                                     unsigned int sensor_units_buflen,
                                     unsigned int abbreviated_units_flag);
 
-void output_sensor_headers (pstdout_state_t pstate,
-                            int quiet_readings,
-                            int output_sensor_state,
-                            int comma_separated_output,
-                            int no_sensor_type_output,
-                            struct sensor_column_width *column_width);
+int sensor_type_listed (pstdout_state_t pstate,
+                        uint8_t sensor_type,
+                        char sensor_types[][MAX_SENSOR_TYPES_STRING_LENGTH+1],
+                        unsigned int sensor_types_length);
+
+int sensor_type_listed_sdr (pstdout_state_t pstate,
+                            ipmi_sdr_parse_ctx_t sdr_parse_ctx,
+                            const void *sdr_record,
+                            unsigned int sdr_record_len,
+                            char sensor_types[][MAX_SENSOR_TYPES_STRING_LENGTH+1],
+                            unsigned int sensor_types_length);
 
 int calculate_entity_id_counts (pstdout_state_t pstate,
                                 ipmi_sdr_cache_ctx_t sdr_cache_ctx,
@@ -137,7 +129,7 @@ int calculate_column_widths (pstdout_state_t pstate,
                              unsigned int sensor_types_length,
                              unsigned int record_ids[],
                              unsigned int record_ids_length,
-                             unsigned int abbreviated_units,
+                             unsigned int non_abbreviated_units,
                              unsigned int shared_sensors,
                              unsigned int count_event_only_records,
                              unsigned int count_device_locator_records,
@@ -145,18 +137,4 @@ int calculate_column_widths (pstdout_state_t pstate,
                              struct sensor_entity_id_counts *entity_id_counts,
                              struct sensor_column_width *column_width);
 
-int calculate_record_ids (pstdout_state_t pstate,
-                          ipmi_sdr_cache_ctx_t sdr_cache_ctx,
-                          ipmi_sdr_parse_ctx_t sdr_parse_ctx,
-                          char sensor_types[][MAX_SENSOR_TYPES_STRING_LENGTH+1],
-                          unsigned int sensor_types_length,
-                          char exclude_sensor_types[][MAX_SENSOR_TYPES_STRING_LENGTH+1],
-                          unsigned int exclude_sensor_types_length,
-                          unsigned int record_ids[],
-                          unsigned int record_ids_length,
-                          unsigned int exclude_record_ids[],
-                          unsigned int exclude_record_ids_length,
-                          unsigned int output_record_ids[MAX_SENSOR_RECORD_IDS],
-                          unsigned int *output_record_ids_length);
-
 #endif
