@@ -1,20 +1,20 @@
 /*
-  Copyright (C) 2007-2010 FreeIPMI Core Team
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2, or (at your option)
-  any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA
-*/
+ * Copyright (C) 2007-2010 FreeIPMI Core Team
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
 
 
 #if HAVE_CONFIG_H
@@ -109,7 +109,7 @@ _get_event_filter_table (struct ipmi_pef_config_state_data *state_data,
   if (ipmi_cmd_get_pef_configuration_parameters_event_filter_table (state_data->ipmi_ctx,
                                                                     IPMI_GET_PEF_PARAMETER,
                                                                     filter_number,
-                                                                    CONFIG_BLOCK_SELECTOR,
+                                                                    IPMI_PEF_CONFIGURATION_PARAMETERS_NO_BLOCK_SELECTOR,
                                                                     obj_cmd_rs) < 0)
     {
       config_err_t ret;
@@ -497,10 +497,16 @@ filter_type_checkout (const char *section_name,
                       struct config_keyvalue *kv,
                       void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -519,10 +525,16 @@ filter_type_commit (const char *section_name,
                     const struct config_keyvalue *kv,
                     void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -540,10 +552,16 @@ enable_filter_checkout (const char *section_name,
                         struct config_keyvalue *kv,
                         void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -562,10 +580,16 @@ enable_filter_commit (const char *section_name,
                       const struct config_keyvalue *kv,
                       void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -583,10 +607,16 @@ event_filter_action_alert_checkout (const char *section_name,
                                     struct config_keyvalue *kv,
                                     void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -605,10 +635,16 @@ event_filter_action_alert_commit (const char *section_name,
                                   const struct config_keyvalue *kv,
                                   void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -626,10 +662,16 @@ event_filter_action_power_off_checkout (const char *section_name,
                                         struct config_keyvalue *kv,
                                         void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -648,10 +690,16 @@ event_filter_action_power_off_commit (const char *section_name,
                                       const struct config_keyvalue *kv,
                                       void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -669,10 +717,16 @@ event_filter_action_reset_checkout (const char *section_name,
                                     struct config_keyvalue *kv,
                                     void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -691,10 +745,16 @@ event_filter_action_reset_commit (const char *section_name,
                                   const struct config_keyvalue *kv,
                                   void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -712,10 +772,16 @@ event_filter_action_power_cycle_checkout (const char *section_name,
                                           struct config_keyvalue *kv,
                                           void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -734,10 +800,16 @@ event_filter_action_power_cycle_commit (const char *section_name,
                                         const struct config_keyvalue *kv,
                                         void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -755,10 +827,16 @@ event_filter_action_oem_checkout (const char *section_name,
                                   struct config_keyvalue *kv,
                                   void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -777,10 +855,16 @@ event_filter_action_oem_commit (const char *section_name,
                                 const struct config_keyvalue *kv,
                                 void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -798,10 +882,16 @@ event_filter_action_diagnostic_interrupt_checkout (const char *section_name,
                                                    struct config_keyvalue *kv,
                                                    void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -820,10 +910,16 @@ event_filter_action_diagnostic_interrupt_commit (const char *section_name,
                                                  const struct config_keyvalue *kv,
                                                  void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -841,10 +937,16 @@ event_filter_action_group_control_operation_checkout (const char *section_name,
                                                       struct config_keyvalue *kv,
                                                       void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -863,10 +965,16 @@ event_filter_action_group_control_operation_commit (const char *section_name,
                                                     const struct config_keyvalue *kv,
                                                     void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -884,10 +992,16 @@ alert_policy_number_checkout (const char *section_name,
                               struct config_keyvalue *kv,
                               void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -906,10 +1020,16 @@ alert_policy_number_commit (const char *section_name,
                             const struct config_keyvalue *kv,
                             void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -927,10 +1047,16 @@ group_control_selector_checkout (const char *section_name,
                                  struct config_keyvalue *kv,
                                  void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -949,10 +1075,16 @@ group_control_selector_commit (const char *section_name,
                                const struct config_keyvalue *kv,
                                void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -970,10 +1102,16 @@ event_severity_checkout (const char *section_name,
                          struct config_keyvalue *kv,
                          void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -992,10 +1130,16 @@ event_severity_commit (const char *section_name,
                        const struct config_keyvalue *kv,
                        void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1013,10 +1157,16 @@ generator_id_byte_1_checkout (const char *section_name,
                               struct config_keyvalue *kv,
                               void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1035,10 +1185,16 @@ generator_id_byte_1_commit (const char *section_name,
                             const struct config_keyvalue *kv,
                             void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1057,10 +1213,16 @@ generator_id_byte_2_checkout (const char *section_name,
                               struct config_keyvalue *kv,
                               void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1079,10 +1241,16 @@ generator_id_byte_2_commit (const char *section_name,
                             const struct config_keyvalue *kv,
                             void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1100,11 +1268,17 @@ sensor_type_checkout (const char *section_name,
                       struct config_keyvalue *kv,
                       void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
   char *str;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1136,11 +1310,17 @@ sensor_type_commit (const char *section_name,
                     const struct config_keyvalue *kv,
                     void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
   int num;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1163,10 +1343,16 @@ sensor_number_checkout (const char *section_name,
                         struct config_keyvalue *kv,
                         void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1185,10 +1371,16 @@ sensor_number_commit (const char *section_name,
                       const struct config_keyvalue *kv,
                       void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1206,10 +1398,16 @@ event_trigger_checkout (const char *section_name,
                         struct config_keyvalue *kv,
                         void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1228,10 +1426,16 @@ event_trigger_commit (const char *section_name,
                       const struct config_keyvalue *kv,
                       void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1249,10 +1453,16 @@ event_data1_offset_mask_checkout (const char *section_name,
                                   struct config_keyvalue *kv,
                                   void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1271,10 +1481,16 @@ event_data1_offset_mask_commit (const char *section_name,
                                 const struct config_keyvalue *kv,
                                 void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1292,10 +1508,16 @@ event_data1_and_mask_checkout (const char *section_name,
                                struct config_keyvalue *kv,
                                void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1314,10 +1536,16 @@ event_data1_and_mask_commit (const char *section_name,
                              const struct config_keyvalue *kv,
                              void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1335,10 +1563,16 @@ event_data1_compare1_checkout (const char *section_name,
                                struct config_keyvalue *kv,
                                void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1357,10 +1591,16 @@ event_data1_compare1_commit (const char *section_name,
                              const struct config_keyvalue *kv,
                              void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1378,10 +1618,16 @@ event_data1_compare2_checkout (const char *section_name,
                                struct config_keyvalue *kv,
                                void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1400,10 +1646,16 @@ event_data1_compare2_commit (const char *section_name,
                              const struct config_keyvalue *kv,
                              void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1421,10 +1673,16 @@ event_data2_and_mask_checkout (const char *section_name,
                                struct config_keyvalue *kv,
                                void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1443,10 +1701,16 @@ event_data2_and_mask_commit (const char *section_name,
                              const struct config_keyvalue *kv,
                              void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1464,10 +1728,16 @@ event_data2_compare1_checkout (const char *section_name,
                                struct config_keyvalue *kv,
                                void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1486,10 +1756,16 @@ event_data2_compare1_commit (const char *section_name,
                              const struct config_keyvalue *kv,
                              void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1507,10 +1783,16 @@ event_data2_compare2_checkout (const char *section_name,
                                struct config_keyvalue *kv,
                                void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1529,10 +1811,16 @@ event_data2_compare2_commit (const char *section_name,
                              const struct config_keyvalue *kv,
                              void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1550,10 +1838,16 @@ event_data3_and_mask_checkout (const char *section_name,
                                struct config_keyvalue *kv,
                                void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1572,10 +1866,16 @@ event_data3_and_mask_commit (const char *section_name,
                              const struct config_keyvalue *kv,
                              void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1593,10 +1893,16 @@ event_data3_compare1_checkout (const char *section_name,
                                struct config_keyvalue *kv,
                                void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1615,10 +1921,16 @@ event_data3_compare1_commit (const char *section_name,
                              const struct config_keyvalue *kv,
                              void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1636,10 +1948,16 @@ event_data3_compare2_checkout (const char *section_name,
                                struct config_keyvalue *kv,
                                void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1658,10 +1976,16 @@ event_data3_compare2_commit (const char *section_name,
                              const struct config_keyvalue *kv,
                              void *arg)
 {
-  ipmi_pef_config_state_data_t *state_data = (ipmi_pef_config_state_data_t *)arg;
+  ipmi_pef_config_state_data_t *state_data;
   config_err_t ret;
   struct event_filter_table eft;
 
+  assert (section_name);
+  assert (kv);
+  assert (arg);
+  
+  state_data = (ipmi_pef_config_state_data_t *)arg;
+
   if ((ret = _get_event_filter_table (state_data,
                                       section_name,
                                       &eft)) != CONFIG_ERR_SUCCESS)
@@ -1675,21 +1999,15 @@ event_data3_compare2_commit (const char *section_name,
 }
 
 struct config_section *
-ipmi_pef_config_event_filter_table_section_get (ipmi_pef_config_state_data_t *state_data, int num)
+ipmi_pef_config_event_filter_table_section_get (ipmi_pef_config_state_data_t *state_data, unsigned int num)
 {
   struct config_section *section = NULL;
   char buf[CONFIG_MAX_SECTION_NAME_LEN];
 
-  if (num <= 0)
-    {
-      pstdout_fprintf (state_data->pstate,
-                       stderr,
-                       "Invalid Num = %d\n",
-                       num);
-      return (NULL);
-    }
+  assert (state_data);
+  assert (num);
 
-  snprintf (buf, CONFIG_MAX_SECTION_NAME_LEN, "Event_Filter_%d", num);
+  snprintf (buf, CONFIG_MAX_SECTION_NAME_LEN, "Event_Filter_%u", num);
 
   if (!(section = config_section_create (state_data->pstate,
                                          buf,
