@@ -1,19 +1,19 @@
 /*
-   Copyright (C) 2003-2010 FreeIPMI Core Team
-
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
+ * Copyright (C) 2003-2010 FreeIPMI Core Team
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
  */
 
 #ifndef _IPMI_SERIAL_MODEM_CMDS_H
@@ -26,6 +26,18 @@ extern "C" {
 #include <stdint.h>
 #include <freeipmi/fiid/fiid.h>
 
+#define IPMI_SERIAL_MODEM_CONFIGURATION_NO_SET_SELECTOR                            0x0
+#define IPMI_SERIAL_MODEM_CONFIGURATION_NO_BLOCK_SELECTOR                          0x0
+
+#define IPMI_SERIAL_MODEM_CONFIGURATION_PARAMETERS_SET_COMPLETE                   0x00
+#define IPMI_SERIAL_MODEM_CONFIGURATION_PARAMETERS_SET_IN_PROGRESS                0x01
+#define IPMI_SERIAL_MODEM_CONFIGURATION_PARAMETERS_SET_COMMIT_WRITE               0x02
+
+#define IPMI_SERIAL_MODEM_CONFIGURATION_PARAMETERS_SET_IN_PROGRESS_VALID(__value) \
+  (((__value) == IPMI_SERIAL_MODEM_CONFIGURATION_PARAMETERS_SET_COMPLETE          \
+    || (__value) == IPMI_SERIAL_MODEM_CONFIGURATION_PARAMETERS_SET_IN_PROGRESS    \
+    || (__value) == IPMI_SERIAL_MODEM_CONFIGURATION_PARAMETERS_SET_COMMIT_WRITE) ? 1 : 0)
+
 #define IPMI_BASIC_MODE_ENABLE                             0x1
 #define IPMI_BASIC_MODE_DISABLE                            0x0
 
@@ -102,6 +114,7 @@ extern "C" {
 
 extern fiid_template_t tmpl_cmd_set_serial_modem_configuration_rq;
 extern fiid_template_t tmpl_cmd_set_serial_modem_configuration_rs;
+extern fiid_template_t tmpl_cmd_set_serial_modem_configuration_set_in_progress_rq;
 extern fiid_template_t tmpl_cmd_set_serial_modem_configuration_connection_mode_rq;
 extern fiid_template_t tmpl_cmd_set_serial_modem_configuration_ipmi_messaging_comm_settings_rq;
 extern fiid_template_t tmpl_cmd_set_serial_modem_configuration_page_blackout_interval_rq;
@@ -109,6 +122,7 @@ extern fiid_template_t tmpl_cmd_set_serial_modem_configuration_call_retry_interv
 
 extern fiid_template_t tmpl_cmd_get_serial_modem_configuration_rq;
 extern fiid_template_t tmpl_cmd_get_serial_modem_configuration_rs;
+extern fiid_template_t tmpl_cmd_get_serial_modem_configuration_set_in_progress_rs;
 extern fiid_template_t tmpl_cmd_get_serial_modem_configuration_connection_mode_rs;
 extern fiid_template_t tmpl_cmd_get_serial_modem_configuration_ipmi_messaging_comm_settings_rs;
 extern fiid_template_t tmpl_cmd_get_serial_modem_configuration_page_blackout_interval_rs;
@@ -120,6 +134,10 @@ int fill_cmd_set_serial_modem_configuration (uint8_t channel_number,
                                              unsigned int configuration_parameter_data_len,
                                              fiid_obj_t obj_cmd_rq);
 
+int fill_cmd_set_serial_modem_configuration_set_in_progress (uint8_t channel_number,
+                                                             uint8_t state,
+                                                             fiid_obj_t obj_cmd_rq);
+
 int fill_cmd_set_serial_modem_configuration_connection_mode (uint8_t channel_number,
                                                              uint8_t basic_mode,
                                                              uint8_t ppp_mode,
